@@ -3,7 +3,7 @@ package Task::Padre::Plugins;
 use warnings;
 use strict;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 
 1;
 __END__
@@ -20,11 +20,11 @@ If not, they run with the whole text from selected document.
 
 =head1 MODULES
 
-=head2 L<Padre::Plugin::AcmePlayCode>
+=head2 L<Acme::Padre::PlayCode>
 
 L<Acme::PlayCode> Plugin for L<Padre>
 
-See L<Padre::Plugin::AcmePlayCode>
+See L<Acme::Padre::PlayCode>
 
 =head2 L<Padre::Plugin::Alarm>
 
@@ -120,6 +120,7 @@ See L<Padre::Plugin::InstallPARDist>
 
 L<Padre> and JavaScript
 
+
 See L<Padre::Plugin::JavaScript>
 
 =head2 L<Padre::Plugin::Kate>
